@@ -130,19 +130,21 @@ rb_encoder_gst_emit_completed (RBEncoderGst *encoder)
 
 	/* find the size of the output file, assuming we can get at it with gio */
 	dest_size = 0;
-	file = g_file_new_for_uri (encoder->priv->dest_uri);
-	file_info = g_file_query_info (file, G_FILE_ATTRIBUTE_STANDARD_SIZE, G_FILE_QUERY_INFO_NONE, NULL, &error);
-	if (error != NULL) {
-		rb_debug ("couldn't get size of destination %s: %s",
-			  encoder->priv->dest_uri,
-			  error->message);
-		g_clear_error (&error);
-	} else {
-		dest_size = g_file_info_get_attribute_uint64 (file_info, G_FILE_ATTRIBUTE_STANDARD_SIZE);
-		rb_debug ("destination file size: %" G_GUINT64_FORMAT, dest_size);
-		g_object_unref (file_info);
+	if (encoder->priv->dest_uri != NULL) {
+		file = g_file_new_for_uri (encoder->priv->dest_uri);
+		file_info = g_file_query_info (file, G_FILE_ATTRIBUTE_STANDARD_SIZE, G_FILE_QUERY_INFO_NONE, NULL, &error);
+		if (error != NULL) {
+			rb_debug ("couldn't get size of destination %s: %s",
+				  encoder->priv->dest_uri,
+				  error->message);
+			g_clear_error (&error);
+		} else {
+			dest_size = g_file_info_get_attribute_uint64 (file_info, G_FILE_ATTRIBUTE_STANDARD_SIZE);
+			rb_debug ("destination file size: %" G_GUINT64_FORMAT, dest_size);
+			g_object_unref (file_info);
+		}
+		g_object_unref (file);
 	}
-	g_object_unref (file);
 
 	encoder->priv->completion_emitted = TRUE;
 	_rb_encoder_emit_completed (RB_ENCODER (encoder), dest_size, encoder->priv->dest_media_type, encoder->priv->error);
@@ -329,11 +331,21 @@ add_tags_from_entry (RBEncoderGst *encoder,
 
 	if (day > 0) {
 		GDate *date;
+		GstDateTime *datetime;
 
 		date = g_date_new_julian (day);
 		gst_tag_list_add (tags, GST_TAG_MERGE_APPEND,
 				  GST_TAG_DATE, date,
 				  NULL);
+
+		datetime = gst_date_time_new_ymd (g_date_get_year (date),
+						  g_date_get_month (date),
+						  g_date_get_day (date));
+		gst_tag_list_add (tags, GST_TAG_MERGE_APPEND,
+				  GST_TAG_DATE_TIME, datetime,
+				  NULL);
+
+		gst_date_time_unref (datetime);
 		g_date_free (date);
 	}
 	add_string_tag (tags, GST_TAG_MERGE_APPEND, GST_TAG_MUSICBRAINZ_TRACKID, entry, RHYTHMDB_PROP_MUSICBRAINZ_TRACKID);
