@@ -21,8 +21,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -32,6 +31,7 @@
 #include "rb-player-gst.h"
 #include "rb-player-gst-xfade.h"
 #include "rb-marshal.h"
+#include "rb-util.h"
 
 /**
  * RBPlayerPlayType:
@@ -599,6 +599,7 @@ rb_player_new (gboolean want_crossfade, GError **error)
 void
 _rb_player_emit_eos (RBPlayer *player, gpointer stream_data, gboolean early)
 {
+	g_assert (rb_is_main_thread ());
 	g_signal_emit (player, signals[EOS], 0, stream_data, early);
 }
 
@@ -618,6 +619,7 @@ _rb_player_emit_info (RBPlayer *player,
 		      RBMetaDataField field,
 		      GValue *value)
 {
+	g_assert (rb_is_main_thread ());
 	g_signal_emit (player, signals[INFO], 0, stream_data, field, value);
 }
 
@@ -633,6 +635,7 @@ _rb_player_emit_info (RBPlayer *player,
 void
 _rb_player_emit_buffering (RBPlayer *player, gpointer stream_data, guint progress)
 {
+	g_assert (rb_is_main_thread ());
 	g_signal_emit (player, signals[BUFFERING], 0, stream_data, progress);
 }
 
@@ -648,6 +651,7 @@ _rb_player_emit_buffering (RBPlayer *player, gpointer stream_data, guint progres
 void
 _rb_player_emit_error (RBPlayer *player, gpointer stream_data, GError *error)
 {
+	g_assert (rb_is_main_thread ());
 	g_signal_emit (player, signals[ERROR], 0, stream_data, error);
 }
 
@@ -664,6 +668,7 @@ _rb_player_emit_error (RBPlayer *player, gpointer stream_data, GError *error)
 void
 _rb_player_emit_tick (RBPlayer *player, gpointer stream_data, gint64 elapsed, gint64 duration)
 {
+	g_assert (rb_is_main_thread ());
 	g_signal_emit (player, signals[TICK], 0, stream_data, elapsed, duration);
 }
 
@@ -680,6 +685,7 @@ _rb_player_emit_tick (RBPlayer *player, gpointer stream_data, gint64 elapsed, gi
 void
 _rb_player_emit_event (RBPlayer *player, gpointer stream_data, const char *name, gpointer data)
 {
+	g_assert (rb_is_main_thread ());
 	g_signal_emit (player, signals[EVENT], g_quark_from_string (name), stream_data, data);
 }
 
@@ -694,6 +700,7 @@ _rb_player_emit_event (RBPlayer *player, gpointer stream_data, const char *name,
 void
 _rb_player_emit_playing_stream (RBPlayer *player, gpointer stream_data)
 {
+	g_assert (rb_is_main_thread ());
 	g_signal_emit (player, signals[PLAYING_STREAM], 0, stream_data);
 }
 
@@ -708,6 +715,7 @@ _rb_player_emit_playing_stream (RBPlayer *player, gpointer stream_data)
 void
 _rb_player_emit_volume_changed (RBPlayer *player, float volume)
 {
+	g_assert (rb_is_main_thread ());
 	g_signal_emit (player, signals[VOLUME_CHANGED], 0, volume);
 }
 
@@ -723,6 +731,7 @@ _rb_player_emit_volume_changed (RBPlayer *player, float volume)
 void
 _rb_player_emit_image (RBPlayer *player, gpointer stream_data, GdkPixbuf *image)
 {
+	g_assert (rb_is_main_thread ());
 	g_signal_emit (player, signals[IMAGE], 0, stream_data, image);
 }
 
@@ -738,6 +747,7 @@ _rb_player_emit_image (RBPlayer *player, gpointer stream_data, GdkPixbuf *image)
 void
 _rb_player_emit_redirect (RBPlayer *player, gpointer stream_data, const char *uri)
 {
+	g_assert (rb_is_main_thread ());
 	g_signal_emit (player, signals[REDIRECT], 0, stream_data, uri);
 }
 
