@@ -464,85 +464,6 @@ impl_dispose (GObject *object)
 	G_OBJECT_CLASS (rb_generic_player_source_parent_class)->dispose (object);
 }
 
-RBSource *
-rb_generic_player_source_new (GObject *plugin, RBShell *shell, GMount *mount, MPIDDevice *device_info)
-{
-	RBGenericPlayerSource *source;
-	RhythmDBEntryType *entry_type;
-	RhythmDBEntryType *error_type;
-	RhythmDBEntryType *ignore_type;
-	RhythmDB *db;
-	GtkBuilder *builder;
-	GMenu *toolbar;
-	GVolume *volume;
-	GSettings *settings;
-	char *name;
-	char *path;
-
-	volume = g_mount_get_volume (mount);
-
-	g_object_get (shell, "db", &db, NULL);
-	path = g_volume_get_identifier (volume, G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE);
-
-	name = g_strdup_printf ("generic audio player: %s", path);
-	entry_type = g_object_new (RHYTHMDB_TYPE_ENTRY_TYPE,
-				   "db", db,
-				   "name", name,
-				   "save-to-disk", FALSE,
-				   "category", RHYTHMDB_ENTRY_NORMAL,
-				   NULL);
-	rhythmdb_register_entry_type (db, entry_type);
-	g_free (name);
-
-	name = g_strdup_printf ("generic audio player (ignore): %s", path);
-	ignore_type = g_object_new (RHYTHMDB_TYPE_ENTRY_TYPE,
-				    "db", db,
-				    "name", name,
-				    "save-to-disk", FALSE,
-				    "category", RHYTHMDB_ENTRY_VIRTUAL,
-				    NULL);
-	rhythmdb_register_entry_type (db, ignore_type);
-	g_free (name);
-
-	name = g_strdup_printf ("generic audio player (errors): %s", path);
-	error_type = g_object_new (RHYTHMDB_TYPE_ENTRY_TYPE,
-				   "db", db,
-				   "name", name,
-				   "save-to-disk", FALSE,
-				   "category", RHYTHMDB_ENTRY_VIRTUAL,
-				   NULL);
-	rhythmdb_register_entry_type (db, error_type);
-	g_free (name);
-
-	g_object_unref (db);
-	g_object_unref (volume);
-	g_free (path);
-
-	builder = rb_builder_load_plugin_file (plugin, "generic-player-toolbar.ui", NULL);
-	toolbar = G_MENU (gtk_builder_get_object (builder, "generic-player-toolbar"));
-	rb_application_link_shared_menus (RB_APPLICATION (g_application_get_default ()), toolbar);
-
-	settings = g_settings_new ("org.gnome.rhythmbox.plugins.generic-player");
-	source = RB_GENERIC_PLAYER_SOURCE (g_object_new (RB_TYPE_GENERIC_PLAYER_SOURCE,
-							 "plugin", plugin,
-							 "entry-type", entry_type,
-							 "ignore-entry-type", ignore_type,
-							 "error-entry-type", error_type,
-							 "mount", mount,
-							 "shell", shell,
-							 "device-info", device_info,
-							 "load-status", RB_SOURCE_LOAD_STATUS_LOADING,
-							 "settings", g_settings_get_child (settings, "source"),
-							 "toolbar-menu", toolbar,
-							 NULL));
-	g_object_unref (settings);
-	g_object_unref (builder);
-
-	rb_shell_register_entry_type_for_source (shell, RB_SOURCE (source), entry_type);
-
-	return RB_SOURCE (source);
-}
-
 static void
 impl_delete_thyself (RBDisplayPage *page)
 {
@@ -596,6 +517,7 @@ import_complete_cb (RhythmDBImportJob *job, int total, RBGenericPlayerSource *so
 {
 	RBGenericPlayerSourceClass *klass = RB_GENERIC_PLAYER_SOURCE_GET_CLASS (source);
 	RBGenericPlayerSourcePrivate *priv = GET_PRIVATE (source);
+	GSettings *settings;
 	RBShell *shell;
 
 	if (priv->ejecting) {
@@ -610,7 +532,11 @@ import_complete_cb (RhythmDBImportJob *job, int total, RBGenericPlayerSource *so
 
 		g_object_set (source, "load-status", RB_SOURCE_LOAD_STATUS_LOADED, NULL);
 
-		rb_transfer_target_transfer (RB_TRANSFER_TARGET (source), NULL, FALSE);
+		g_object_get (source, "encoding-settings", &settings, NULL);
+		rb_transfer_target_transfer (RB_TRANSFER_TARGET (source), settings, NULL, FALSE);
+		g_object_unref (settings);
+
+		rb_media_player_source_purge_metadata_cache (RB_MEDIA_PLAYER_SOURCE (source));
 	}
 
 	g_object_unref (priv->import_job);
@@ -962,9 +888,14 @@ static RBTrackTransferBatch *
 impl_paste (RBSource *source, GList *entries)
 {
 	gboolean defer;
+	GSettings *settings;
+	RBTrackTransferBatch *batch;
 
 	defer = (ensure_loaded (RB_GENERIC_PLAYER_SOURCE (source)) == FALSE);
-	return rb_transfer_target_transfer (RB_TRANSFER_TARGET (source), entries, defer);
+	g_object_get (source, "encoding-settings", &settings, NULL);
+	batch = rb_transfer_target_transfer (RB_TRANSFER_TARGET (source), settings, entries, defer);
+	g_object_unref (settings);
+	return batch;
 }
 
 static gboolean
