@@ -599,6 +599,7 @@ rb_mtp_source_new (RBShell *shell,
 #endif
 					      "load-status", RB_SOURCE_LOAD_STATUS_LOADING,
 					      "settings", g_settings_get_child (settings, "source"),
+					      "encoding-settings", g_settings_get_child (settings, "encoding"),
 					      "toolbar-menu", toolbar,
 					      "name", _("Media Player"),
 					      NULL));
@@ -981,8 +982,12 @@ mtp_device_open_cb (LIBMTP_mtpdevice_t *device, RBMtpSource *source)
 static gboolean
 device_loaded_idle (RBMtpSource *source)
 {
+	GSettings *settings;
+
 	g_object_set (source, "load-status", RB_SOURCE_LOAD_STATUS_LOADED, NULL);
-	rb_transfer_target_transfer (RB_TRANSFER_TARGET (source), NULL, FALSE);
+	g_object_get (source, "encoding-settings", &settings, NULL);
+	rb_transfer_target_transfer (RB_TRANSFER_TARGET (source), settings, NULL, FALSE);
+	g_object_unref (settings);
 	return FALSE;
 }
 
@@ -1077,8 +1082,14 @@ static RBTrackTransferBatch *
 impl_paste (RBSource *source, GList *entries)
 {
 	gboolean defer;
+	RBTrackTransferBatch *batch;
+	GSettings *settings;
+
 	defer = (ensure_loaded (RB_MTP_SOURCE (source)) == FALSE);
-	return rb_transfer_target_transfer (RB_TRANSFER_TARGET (source), entries, defer);
+	g_object_get (source, "encoding-settings", &settings, NULL);
+	batch = rb_transfer_target_transfer (RB_TRANSFER_TARGET (source), settings, entries, defer);
+	g_object_unref (settings);
+	return batch;
 }
 
 static RhythmDB *
@@ -1174,13 +1185,6 @@ impl_track_add_error (RBTransferTarget *target,
 	return TRUE;
 }
 
-static void
-sanitize_for_mtp (char *str)
-{
-	rb_sanitize_path_for_msdos_filesystem (str);
-	g_strdelimit (str, "/", '_');
-}
-
 static void
 prepare_encoder_sink_cb (RBEncoderFactory *factory,
 			 const char *stream_uri,
@@ -1252,9 +1256,9 @@ prepare_encoder_sink_cb (RBEncoderFactory *factory,
 	folder_path[1] = rhythmdb_entry_dup_string (entry, RHYTHMDB_PROP_ALBUM);
 
 	/* ensure the filename is safe for FAT filesystems and doesn't contain slashes */
-	sanitize_for_mtp (track->filename);
-	sanitize_for_mtp (folder_path[0]);
-	sanitize_for_mtp (folder_path[1]);
+	rb_sanitize_path_for_msdos_filesystem (track->filename);
+	rb_sanitize_path_for_msdos_filesystem (folder_path[0]);
+	rb_sanitize_path_for_msdos_filesystem (folder_path[1]);
 
 	if (rhythmdb_entry_get_ulong (entry, RHYTHMDB_PROP_DATE) > 0) {
 		g_date_set_julian (&d, rhythmdb_entry_get_ulong (entry, RHYTHMDB_PROP_DATE));
