@@ -402,10 +402,7 @@ podcast_add_action_cb (GSimpleAction *action, GVariant *parameter, gpointer data
 void
 rb_podcast_source_add_feed (RBPodcastSource *source, const char *text)
 {
-	GtkWidget *window;
-
-	window = gtk_widget_get_toplevel (GTK_WIDGET (source));
-	g_action_group_activate_action (G_ACTION_GROUP (window), "podcast-add", NULL);
+	g_action_group_activate_action (G_ACTION_GROUP (g_application_get_default ()), "podcast-add", NULL);
 
 	rb_podcast_add_dialog_reset (RB_PODCAST_ADD_DIALOG (source->priv->add_dialog), text, TRUE);
 }
@@ -534,7 +531,7 @@ podcast_feed_delete_action_cb (GSimpleAction *action, GVariant *parameter, gpoin
 	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
 	                        _("Delete _Feed Only"),
 	                        GTK_RESPONSE_NO,
-	                        GTK_STOCK_CANCEL,
+	                        _("_Cancel"),
 	                        GTK_RESPONSE_CANCEL,
 	                        NULL);
 
@@ -1035,34 +1032,6 @@ impl_add_to_queue (RBSource *source, RBSource *queue)
 	g_list_free (selection);
 }
 
-static gboolean
-impl_can_add_to_queue (RBSource *source)
-{
-	RBEntryView *songs;
-	GList *selection;
-	GList *iter;
-	gboolean ok = FALSE;
-
-	songs = rb_source_get_entry_view (source);
-	selection = rb_entry_view_get_selected_entries (songs);
-
-	if (selection == NULL)
-		return FALSE;
-
-	/* If at least one entry has been downloaded, enable add to queue.
-	 * We'll filter out those that haven't when adding to the queue.
-	 */
-	for (iter = selection; iter && !ok; iter = iter->next) {
-		RhythmDBEntry *entry = (RhythmDBEntry *)iter->data;
-		ok |= rb_podcast_manager_entry_downloaded (entry);
-	}
-
-	g_list_foreach (selection, (GFunc)rhythmdb_entry_unref, NULL);
-	g_list_free (selection);
-
-	return ok;
-}
-
 static void
 delete_response_cb (GtkDialog *dialog, int response, RBPodcastSource *source)
 {
@@ -1101,7 +1070,7 @@ delete_response_cb (GtkDialog *dialog, int response, RBPodcastSource *source)
 }
 
 static void
-impl_delete (RBSource *asource)
+impl_delete_selected (RBSource *asource)
 {
 	RBPodcastSource *source = RB_PODCAST_SOURCE (asource);
 	GtkWidget *dialog;
@@ -1132,7 +1101,7 @@ impl_delete (RBSource *asource)
 	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
 	                        _("Delete _Episode Only"),
 	                        GTK_RESPONSE_NO,
-	                        GTK_STOCK_CANCEL,
+	                        _("_Cancel"),
 	                        GTK_RESPONSE_CANCEL,
 	                        NULL);
 	button = gtk_dialog_add_button (GTK_DIALOG (dialog),
@@ -1680,17 +1649,17 @@ rb_podcast_source_class_init (RBPodcastSourceClass *klass)
 	page_class->receive_drag = impl_receive_drag;
 
 	source_class->reset_filters = impl_reset_filters;
-	source_class->impl_add_to_queue = impl_add_to_queue;
-	source_class->impl_can_add_to_queue = impl_can_add_to_queue;
-	source_class->impl_can_copy = (RBSourceFeatureFunc) rb_false_function;
-	source_class->impl_can_cut = (RBSourceFeatureFunc) rb_false_function;
-	source_class->impl_can_delete = (RBSourceFeatureFunc) rb_true_function;
-	source_class->impl_delete = impl_delete;
-	source_class->impl_get_entry_view = impl_get_entry_view;
-	source_class->impl_handle_eos = impl_handle_eos;
-	source_class->impl_search = impl_search;
-	source_class->impl_song_properties = impl_song_properties;
-	source_class->impl_get_delete_label = impl_get_delete_label;
+	source_class->add_to_queue = impl_add_to_queue;
+	source_class->can_add_to_queue = (RBSourceFeatureFunc) rb_true_function;
+	source_class->can_copy = (RBSourceFeatureFunc) rb_false_function;
+	source_class->can_cut = (RBSourceFeatureFunc) rb_false_function;
+	source_class->can_delete = (RBSourceFeatureFunc) rb_true_function;
+	source_class->delete_selected = impl_delete_selected;
+	source_class->get_entry_view = impl_get_entry_view;
+	source_class->handle_eos = impl_handle_eos;
+	source_class->search = impl_search;
+	source_class->song_properties = impl_song_properties;
+	source_class->get_delete_label = impl_get_delete_label;
 
 	g_object_class_install_property (object_class,
 					 PROP_PODCAST_MANAGER,
