@@ -60,9 +60,6 @@ struct _RBTrackTransferBatchClass
 	void	(*cancelled)		(RBTrackTransferBatch *batch);
 	void	(*complete)		(RBTrackTransferBatch *batch);
 
-	char *	(*configure_profile)	(RBTrackTransferBatch *batch,
-					 const char *mediatype,
-					 GstEncodingProfile *profile);
 	char *  (*get_dest_uri)		(RBTrackTransferBatch *batch,
 					 RhythmDBEntry *entry,
 					 const char *mediatype,
@@ -82,12 +79,14 @@ struct _RBTrackTransferBatchClass
 					 RhythmDBEntry *entry,
 					 const char *dest,
 					 guint64 dest_size,
+					 const char *mediatype,
 					 GError *error);
 };
 
 GType			rb_track_transfer_batch_get_type	(void);
 
 RBTrackTransferBatch *	rb_track_transfer_batch_new		(GstEncodingTarget *target,
+								 GSettings *settings,
 								 GObject *source,
 								 GObject *destination);
 void			rb_track_transfer_batch_add		(RBTrackTransferBatch *batch,
