@@ -51,7 +51,6 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <glib-object.h>
-#include <gst/pbutils/install-plugins.h>
 
 #include "rb-track-transfer-batch.h"
 #include "rb-track-transfer-queue.h"
@@ -65,9 +64,8 @@
 #include "rb-library-source.h"
 #include "rb-auto-playlist-source.h"
 #include "rb-encoder.h"
-#include "rb-missing-plugins.h"
 #include "rb-gst-media-types.h"
-#include "rb-object-property-editor.h"
+#include "rb-encoding-settings.h"
 #include "rb-import-dialog.h"
 #include "rb-application.h"
 #include "rb-display-page-menu.h"
@@ -111,12 +109,6 @@ static void rb_library_source_path_changed_cb (GtkComboBox *box,
 						RBLibrarySource *source);
 static void rb_library_source_filename_changed_cb (GtkComboBox *box,
 						   RBLibrarySource *source);
-static void rb_library_source_format_changed_cb (GtkWidget *widget,
-						 RBLibrarySource *source);
-static void rb_library_source_preset_changed_cb (GtkWidget *widget,
-						 RBLibrarySource *source);
-static void rb_library_source_install_plugins_cb (GtkWidget *widget,
-						  RBLibrarySource *source);
 static void update_layout_example_label (RBLibrarySource *source);
 static RhythmDBImportJob *maybe_create_import_job (RBLibrarySource *source);
 
@@ -144,19 +136,6 @@ static const LibraryPathElement library_layout_filenames[] = {
 };
 static const int num_library_layout_filenames = G_N_ELEMENTS (library_layout_filenames);
 
-#define CUSTOM_SETTINGS_PREFIX "rhythmbox-custom-settings"
-#define CBR_SETTINGS_PRESET CUSTOM_SETTINGS_PREFIX "-cbr"
-/* this preset name was used in releases where we only had VBR custom settings */
-#define VBR_SETTINGS_PRESET CUSTOM_SETTINGS_PREFIX
-
-static struct {
-	const char *style;
-	const char *label;
-	const char *preset;
-} library_encoding_styles[] = {
-	{ "cbr", N_("Constant bit rate"), CBR_SETTINGS_PRESET },
-	{ "vbr", N_("Variable bit rate"), VBR_SETTINGS_PRESET },
-};
 
 
 struct RBLibrarySourcePrivate
@@ -175,21 +154,10 @@ struct RBLibrarySourcePrivate
 	GtkWidget *watch_library_check;
 	GtkWidget *layout_path_menu;
 	GtkWidget *layout_filename_menu;
-	GtkWidget *preferred_format_menu;
-	GtkWidget *preset_menu;
 	GtkWidget *layout_example_label;
-	GtkWidget *install_plugins_button;
-	GtkWidget *encoder_property_holder;
-	GtkWidget *encoder_property_editor;
-	GtkTreeModel *profile_model;
-	GtkTreeModel *preset_model;
 
-	GstElement *encoder_element;
 	GList *import_jobs;
 	guint start_import_job_id;
-	gulong profile_changed_id;
-	gboolean profile_init;
-	char *preset_name;
 	gboolean do_initial_import;
 
 	GSettings *settings;
@@ -597,220 +565,13 @@ update_layout_filename (RBLibrarySource *source)
 }
 
 static void
-insert_preset (RBLibrarySource *source, const char *display_name, const char *name, gboolean select)
+encoding_settings_changed_cb (GSettings *settings, const char *key, RBLibrarySource *source)
 {
-	GtkTreeIter iter;
-
-	gtk_list_store_insert_with_values (GTK_LIST_STORE (source->priv->preset_model),
-					   &iter,
-					   -1,
-					   0, display_name,
-					   1, name,
-					   -1);
-	if (select) {
-		rb_debug ("preset %s is selected", display_name);
-		gtk_combo_box_set_active_iter (GTK_COMBO_BOX (source->priv->preset_menu), &iter);
+	if (g_strcmp0 (key, "media-type") == 0) {
+		update_layout_example_label (source);
 	}
 }
 
-static void
-profile_changed_cb (RBObjectPropertyEditor *editor, RBLibrarySource *source)
-{
-	if (source->priv->profile_init)
-		return;
-
-	if (source->priv->encoder_element) {
-		rb_debug ("updating preset %s", source->priv->preset_name);
-		gst_preset_save_preset (GST_PRESET (source->priv->encoder_element),
-						    source->priv->preset_name);
-	}
-}
-
-static void
-update_property_editor_for_preset (RBLibrarySource *source, const char *media_type, const char *preset)
-{
-	int i;
-	int style;
-
-	/* figure out if this is a user-settings preset name */
-	style = -1;
-	for (i = 0; i < G_N_ELEMENTS (library_encoding_styles); i++) {
-		if (g_strcmp0 (preset, library_encoding_styles[i].preset) == 0) {
-			style = i;
-			break;
-		}
-	}
-
-	/* remove old property editor, if there is one */
-	if (source->priv->encoder_property_editor != NULL) {
-		g_signal_handler_disconnect (source->priv->encoder_property_editor,
-					     source->priv->profile_changed_id);
-
-		gtk_container_remove (GTK_CONTAINER (source->priv->encoder_property_holder),
-				      source->priv->encoder_property_editor);
-		source->priv->profile_changed_id = 0;
-		source->priv->encoder_property_editor = NULL;
-		g_free (source->priv->preset_name);
-		source->priv->preset_name = NULL;
-	}
-
-	/* create new property editor, if required */
-	if (style != -1 && source->priv->encoder_element) {
-		GstEncodingProfile *profile;
-		char **profile_settings;
-
-		/* make sure the preset exists so encoder batches can use it */
-		if (gst_preset_load_preset (GST_PRESET (source->priv->encoder_element), preset) == FALSE) {
-			if (rb_gst_encoder_set_encoding_style (source->priv->encoder_element,
-							       library_encoding_styles[style].style)) {
-				gst_preset_save_preset (GST_PRESET (source->priv->encoder_element),
-							preset);
-			}
-		}
-
-		profile = rb_gst_get_encoding_profile (media_type);
-		profile_settings =
-			rb_gst_encoding_profile_get_settings (profile,
-							      library_encoding_styles[style].style);
-		source->priv->encoder_property_editor =
-			rb_object_property_editor_new (G_OBJECT (source->priv->encoder_element),
-						       profile_settings);
-		g_strfreev (profile_settings);
-		gst_encoding_profile_unref (profile);
-
-		source->priv->profile_changed_id =
-			g_signal_connect (source->priv->encoder_property_editor,
-					  "changed",
-					  G_CALLBACK (profile_changed_cb),
-					  source);
-
-		gtk_grid_attach (GTK_GRID (source->priv->encoder_property_holder),
-				 source->priv->encoder_property_editor,
-				 0, 0, 1, 1);
-		gtk_widget_show_all (source->priv->encoder_property_editor);
-
-		source->priv->preset_name = g_strdup (preset);
-	}
-}
-
-static void
-update_presets (RBLibrarySource *source, const char *media_type)
-{
-	GVariant *preset_settings;
-	char *active_preset;
-	GstEncodingProfile *profile;
-	char **profile_settings;
-	char **profile_presets;
-	int i;
-
-	source->priv->profile_init = TRUE;
-
-	gtk_list_store_clear (GTK_LIST_STORE (source->priv->preset_model));
-
-	if (source->priv->encoder_element != NULL) {
-		gst_object_unref (source->priv->encoder_element);
-		source->priv->encoder_element = NULL;
-	}
-
-	gtk_widget_set_sensitive (source->priv->preset_menu, FALSE);
-	if (media_type == NULL) {
-		source->priv->profile_init = FALSE;
-		return;
-	}
-
-	/* get preset for the media type from settings */
-	preset_settings = g_settings_get_value (source->priv->encoding_settings, "media-type-presets");
-	active_preset = NULL;
-	g_variant_lookup (preset_settings, media_type, "s", &active_preset);
-
-	rb_debug ("active preset for media type %s is %s", media_type, active_preset);
-
-	insert_preset (source,
-		       _("Default settings"),
-		       "",
-		       (active_preset == NULL || active_preset[0] == '\0'));
-
-	profile = rb_gst_get_encoding_profile (media_type);
-	if (profile == NULL) {
-		g_warning ("Don't know how to encode to media type %s", media_type);
-		source->priv->profile_init = FALSE;
-		return;
-	}
-	source->priv->encoder_element = rb_gst_encoding_profile_get_encoder (profile);
-
-	for (i = 0; i < G_N_ELEMENTS (library_encoding_styles); i++) {
-		profile_settings = rb_gst_encoding_profile_get_settings (profile, library_encoding_styles[i].style);
-		if (profile_settings == NULL)
-			continue;
-
-		rb_debug ("profile has custom settings for style %s", library_encoding_styles[i].style);
-		insert_preset (source,
-			       gettext (library_encoding_styles[i].label),
-			       library_encoding_styles[i].preset,
-			       g_strcmp0 (active_preset, library_encoding_styles[i].preset) == 0);
-		gtk_widget_set_sensitive (source->priv->preset_menu, TRUE);
-	}
-
-	/* get list of actual presets for the media type */
-	profile_presets = rb_gst_encoding_profile_get_presets (profile);
-	if (profile_presets) {
-		int i;
-		for (i = 0; profile_presets[i] != NULL; i++) {
-			if (g_str_has_prefix (profile_presets[i], CUSTOM_SETTINGS_PREFIX))
-				continue;
-
-			rb_debug ("profile has preset %s", profile_presets[i]);
-			insert_preset (source,
-				       profile_presets[i],
-				       profile_presets[i],
-				       g_strcmp0 (profile_presets[i], active_preset) == 0);
-			gtk_widget_set_sensitive (source->priv->preset_menu, TRUE);
-		}
-		g_strfreev (profile_presets);
-	}
-
-	update_property_editor_for_preset (source, media_type, active_preset);
-
-	gst_encoding_profile_unref (profile);
-	source->priv->profile_init = FALSE;
-}
-
-static void
-update_preferred_media_type (RBLibrarySource *source)
-{
-	GtkTreeIter iter;
-	gboolean done;
-	char *str;
-
-	if (source->priv->profile_model == NULL)
-		return;
-
-	done = FALSE;
-	str = g_settings_get_string (source->priv->encoding_settings, "media-type");
-	if (gtk_tree_model_get_iter_first (source->priv->profile_model, &iter)) {
-		do {
-			char *media_type;
-
-			gtk_tree_model_get (source->priv->profile_model, &iter,
-					    0, &media_type,
-					    -1);
-			if (g_strcmp0 (media_type, str) == 0) {
-				gtk_combo_box_set_active_iter (GTK_COMBO_BOX (source->priv->preferred_format_menu), &iter);
-				update_presets (source, media_type);
-				done = TRUE;
-			}
-			g_free (media_type);
-		} while (done == FALSE && gtk_tree_model_iter_next (source->priv->profile_model, &iter));
-	}
-
-	if (done == FALSE) {
-		gtk_combo_box_set_active_iter (GTK_COMBO_BOX (source->priv->preferred_format_menu), NULL);
-		update_presets (source, NULL);
-	}
-
-	g_free (str);
-}
-
 static void
 db_settings_changed_cb (GSettings *settings, const char *key, RBLibrarySource *source)
 {
@@ -832,30 +593,14 @@ library_settings_changed_cb (GSettings *settings, const char *key, RBLibrarySour
 	}
 }
 
-static void
-encoding_settings_changed_cb (GSettings *settings, const char *key, RBLibrarySource *source)
-{
-	if (g_strcmp0 (key, "media-type") == 0) {
-		rb_debug ("preferred media type changed");
-		update_preferred_media_type (source);
-	} else if (g_strcmp0 (key, "media-type-presets") == 0) {
-		rb_debug ("media type presets changed");
-		/* need to do anything here?  update selection if the
-		 * preset for the preferred media type changed?
-		 */
-	}
-}
-
 static GtkWidget *
 impl_get_config_widget (RBDisplayPage *asource, RBShellPreferences *prefs)
 {
 	RBLibrarySource *source = RB_LIBRARY_SOURCE (asource);
-	GtkCellRenderer *renderer;
-	GstEncodingTarget *target;
 	GtkBuilder *builder;
 	GObject *tmp;
 	GObject *label;
-	const GList *p;
+	GtkWidget *holder;
 	int i;
 
 	if (source->priv->config_widget)
@@ -916,62 +661,15 @@ impl_get_config_widget (RBDisplayPage *asource, RBShellPreferences *prefs)
 						_(library_layout_filenames[i].title));
 	}
 
-	target = rb_gst_get_default_encoding_target ();
-	source->priv->profile_model = GTK_TREE_MODEL (gtk_tree_store_new (3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER));
-	for (p = gst_encoding_target_get_profiles (target); p != NULL; p = p->next) {
-		GstEncodingProfile *profile = GST_ENCODING_PROFILE (p->data);
-		char *media_type;
-
-		media_type = rb_gst_encoding_profile_get_media_type (profile);
-		if (media_type == NULL) {
-			continue;
-		}
-		gtk_tree_store_insert_with_values (GTK_TREE_STORE (source->priv->profile_model),
-						   NULL,
-						   NULL,
-						   -1,
-						   0, media_type,
-						   1, gst_encoding_profile_get_description (profile),
-						   2, profile,
-						   -1);
-		g_free (media_type);
-	}
-
-	source->priv->preset_model = GTK_TREE_MODEL (gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING));
-
-	source->priv->preferred_format_menu = GTK_WIDGET (gtk_builder_get_object (builder, "format_select_combo"));
-	gtk_combo_box_set_model (GTK_COMBO_BOX (source->priv->preferred_format_menu), source->priv->profile_model);
-	renderer = gtk_cell_renderer_text_new ();
-	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (source->priv->preferred_format_menu), renderer, TRUE);
-	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (source->priv->preferred_format_menu), renderer, "text", 1, NULL);
-
-	g_signal_connect (source->priv->preferred_format_menu,
-			  "changed",
-			  G_CALLBACK (rb_library_source_format_changed_cb),
-			  asource);
-
-	source->priv->preset_menu = GTK_WIDGET (gtk_builder_get_object (builder, "preset_select_combo"));
-	gtk_combo_box_set_model (GTK_COMBO_BOX (source->priv->preset_menu), source->priv->preset_model);
-	renderer = gtk_cell_renderer_text_new ();
-	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (source->priv->preset_menu), renderer, TRUE);
-	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (source->priv->preset_menu), renderer, "text", 0, NULL);
-
-	g_signal_connect (source->priv->preset_menu,
-			  "changed",
-			  G_CALLBACK (rb_library_source_preset_changed_cb),
-			  asource);
-
+	holder = GTK_WIDGET (gtk_builder_get_object (builder, "encoding_settings_holder"));
+	gtk_container_add (GTK_CONTAINER (holder),
+			   rb_encoding_settings_new (source->priv->encoding_settings,
+						     rb_gst_get_default_encoding_target (),
+						     FALSE));
 
 	source->priv->layout_example_label = GTK_WIDGET (gtk_builder_get_object (builder, "layout_example_label"));
 
-	source->priv->install_plugins_button = GTK_WIDGET (gtk_builder_get_object (builder, "install_plugins_button"));
-	gtk_widget_set_no_show_all (source->priv->install_plugins_button, TRUE);
-	g_signal_connect (source->priv->install_plugins_button, "clicked", G_CALLBACK (rb_library_source_install_plugins_cb), source);
-
-	source->priv->encoder_property_holder = GTK_WIDGET (gtk_builder_get_object (builder, "encoder_property_holder"));
-
 	update_library_locations (source);
-	update_preferred_media_type (source);
 
 	update_layout_path (source);
 	update_layout_filename (source);
@@ -1075,170 +773,6 @@ rb_library_source_filename_changed_cb (GtkComboBox *box, RBLibrarySource *source
 	}
 }
 
-static void
-rb_library_source_format_changed_cb (GtkWidget *widget, RBLibrarySource *source)
-{
-	GtkTreeIter iter;
-	char *media_type = NULL;
-	GstEncodingProfile *profile;
-	RBEncoder *encoder;
-
-	if (source->priv->profile_init)
-		return;
-
-	/* get selected media type */
-	if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (widget), &iter) == FALSE)
-		return;
-	gtk_tree_model_get (GTK_TREE_MODEL (source->priv->profile_model),
-			    &iter,
-			    0, &media_type,
-			    2, &profile,
-			    -1);
-
-	g_settings_set_string (source->priv->encoding_settings, "media-type", media_type);
-
-	update_layout_example_label (source);
-
-	/* indicate whether additional plugins are required to encode in this format */
-	encoder = rb_encoder_new ();
-	if (rb_encoder_get_missing_plugins (encoder, profile, NULL, NULL)) {
-		rb_debug ("additional plugins are required to encode %s", media_type);
-		gtk_widget_set_visible (source->priv->install_plugins_button, TRUE);
-		/* not a great way to handle this situation; probably should describe
-		 * the plugins that are missing when automatic install isn't available.
-		 */
-		gtk_widget_set_sensitive (source->priv->install_plugins_button,
-					gst_install_plugins_supported ());
-	} else {
-		rb_debug ("can encode %s", media_type);
-		gtk_widget_set_visible (source->priv->install_plugins_button, FALSE);
-	}
-	g_free (media_type);
-}
-
-static void
-rb_library_source_preset_changed_cb (GtkWidget *widget, RBLibrarySource *source)
-{
-	GtkTreeIter iter;
-	char *media_type = NULL;
-	char *preset = NULL;
-	char *stored;
-	gboolean have_preset;
-	GVariant *settings;
-
-	if (source->priv->profile_init)
-		return;
-
-	/* get selected media type */
-	if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (source->priv->preferred_format_menu), &iter) == FALSE) {
-		rb_debug ("no media type selected?");
-		return;
-	}
-	gtk_tree_model_get (GTK_TREE_MODEL (source->priv->profile_model),
-			    &iter,
-			    0, &media_type,
-			    -1);
-
-	/* get selected preset */
-	if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (source->priv->preset_menu), &iter)) {
-		gtk_tree_model_get (GTK_TREE_MODEL (source->priv->preset_model),
-				    &iter,
-				    1, &preset,
-				    -1);
-		rb_debug ("preset %s now selected for media type %s", preset, media_type);
-	} else {
-		rb_debug ("no preset selected for media type %s?", media_type);
-	}
-
-	update_property_editor_for_preset (source, media_type, preset);
-
-	/* store selected preset */
-	settings = g_settings_get_value (source->priv->encoding_settings, "media-type-presets");
-	stored = NULL;
-	have_preset = (preset != NULL && preset[0] != '\0');
-	g_variant_lookup (settings, media_type, "s", &stored);
-	if (have_preset == FALSE && (stored == NULL || stored[0] == '\0')) {
-		/* don't bother */
-	} else if (g_strcmp0 (stored, preset) != 0) {
-		GVariantBuilder b;
-		GVariantIter i;
-		char *mt;
-		char *p;
-		gboolean stored;
-
-		g_variant_builder_init (&b, G_VARIANT_TYPE ("a{ss}"));
-		g_variant_iter_init (&i, settings);
-		stored = FALSE;
-		while (g_variant_iter_loop (&i, "{ss}", &mt, &p)) {
-			if (g_strcmp0 (mt, media_type) == 0) {
-				if (have_preset) {
-					g_variant_builder_add (&b, "{ss}", mt, preset);
-				}
-				stored = TRUE;
-			} else {
-				g_variant_builder_add (&b, "{ss}", mt, p);
-				rb_debug ("keeping %s => %s", mt, p);
-			}
-		}
-
-		if (have_preset && stored == FALSE) {
-			g_variant_builder_add (&b, "{ss}", media_type, preset);
-		}
-
-		g_settings_set_value (source->priv->encoding_settings, "media-type-presets", g_variant_builder_end (&b));
-	}
-	g_variant_unref (settings);
-
-	g_free (stored);
-	g_free (preset);
-	g_free (media_type);
-}
-
-static void
-plugin_install_done_cb (gpointer inst, gboolean retry, RBLibrarySource *source)
-{
-	rb_library_source_format_changed_cb (source->priv->preferred_format_menu, source);
-}
-
-static void
-rb_library_source_install_plugins_cb (GtkWidget *widget, RBLibrarySource *source)
-{
-	char *media_type;
-	GstEncodingProfile *profile;
-	RBEncoder *encoder;
-	char **details;
-	GClosure *closure;
-
-	/* get profile */
-	media_type = g_settings_get_string (source->priv->encoding_settings, "media-type");
-	profile = rb_gst_get_encoding_profile (media_type);
-	if (profile == NULL) {
-		g_warning ("no encoding profile available for %s, so how can we install plugins?",
-			   media_type);
-		g_free (media_type);
-		return;
-	}
-	g_free (media_type);
-
-	/* get plugin details */
-	encoder = rb_encoder_new ();
-	if (rb_encoder_get_missing_plugins (encoder, profile, &details, NULL) == FALSE) {
-		/* what? */
-		g_object_unref (encoder);
-		return;
-	}
-
-	/* attempt installation */
-	closure = g_cclosure_new ((GCallback) plugin_install_done_cb,
-				  g_object_ref (source),
-				  (GClosureNotify) g_object_unref);
-	g_closure_set_marshal (closure, g_cclosure_marshal_VOID__BOOLEAN);
-
-	rb_missing_plugins_install ((const char **)details, TRUE, closure);
-
-	g_closure_sink (closure);
-	g_strfreev (details);
-}
 
 /*
  * Perform magic on a path to make it safe.
@@ -1639,25 +1173,6 @@ get_dest_uri_cb (RBTrackTransferBatch *batch,
 	return sane_dest;
 }
 
-static void
-configure_profile_cb (RBTrackTransferBatch *batch,
-		      const char *media_type,
-		      GstEncodingProfile *profile,
-		      RBLibrarySource *source)
-{
-	GVariant *preset_settings;
-	char *active_preset;
-
-	preset_settings = g_settings_get_value (source->priv->encoding_settings, "media-type-presets");
-	active_preset = NULL;
-	g_variant_lookup (preset_settings, media_type, "s", &active_preset);
-
-	rb_debug ("setting preset %s for media type %s", active_preset, media_type);
-	rb_gst_encoding_profile_set_preset (profile, active_preset);
-
-	g_free (active_preset);
-}
-
 static void
 track_done_cb (RBTrackTransferBatch *batch,
 	       RhythmDBEntry *entry,
@@ -1724,9 +1239,6 @@ impl_paste (RBSource *asource, GList *entries)
 	preferred_media_type = g_settings_get_string (source->priv->encoding_settings, "media-type");
 	profile = rb_gst_get_encoding_profile (preferred_media_type);
 	g_free (preferred_media_type);
-	/* have a preset as part of the user settings too?  would that work for containerful streams,
-	 * where the interesting settings are on the stream inside the container?
-	 */
 	if (profile != NULL) {
 		gst_encoding_target_add_profile (target, profile);
 	}
@@ -1736,10 +1248,9 @@ impl_paste (RBSource *asource, GList *entries)
 	gst_encoding_profile_set_name (profile, "copy");
 	gst_encoding_target_add_profile (target, profile);
 
-	batch = rb_track_transfer_batch_new (target, NULL, G_OBJECT (source));
+	batch = rb_track_transfer_batch_new (target, source->priv->encoding_settings, NULL, G_OBJECT (source));
 	g_signal_connect_object (batch, "get-dest-uri", G_CALLBACK (get_dest_uri_cb), source, 0);
 	g_signal_connect_object (batch, "track-done", G_CALLBACK (track_done_cb), source, 0);
-	g_signal_connect_object (batch, "configure-profile", G_CALLBACK (configure_profile_cb), source, 0);
 
 	for (l = entries; l != NULL; l = g_list_next (l)) {
 		RhythmDBEntry *entry = (RhythmDBEntry *)l->data;
