@@ -46,6 +46,12 @@
 #include "rb-builder-helpers.h"
 #include "rb-playlist-manager.h"
 #include "rb-util.h"
+#include "rb-encoding-settings.h"
+
+typedef struct {
+	char *uri_prefix;
+	char *key_prefix;
+} RBMediaPlayerEntryTypePrivate;
 
 typedef struct {
 	RBSyncSettings *sync_settings;
@@ -68,11 +74,18 @@ typedef struct {
 	gboolean syncing;
 
 	GstEncodingTarget *encoding_target;
+	GSettings *encoding_settings;
 } RBMediaPlayerSourcePrivate;
 
 G_DEFINE_TYPE (RBMediaPlayerSource, rb_media_player_source, RB_TYPE_BROWSER_SOURCE);
 
+G_DEFINE_TYPE (RBMediaPlayerEntryType, rb_media_player_entry_type, RHYTHMDB_TYPE_ENTRY_TYPE);
+
 #define MEDIA_PLAYER_SOURCE_GET_PRIVATE(o)   (G_TYPE_INSTANCE_GET_PRIVATE ((o), RB_TYPE_MEDIA_PLAYER_SOURCE, RBMediaPlayerSourcePrivate))
+#define MEDIA_PLAYER_ENTRY_TYPE_GET_PRIVATE(o)   (G_TYPE_INSTANCE_GET_PRIVATE ((o), RB_TYPE_MEDIA_PLAYER_ENTRY_TYPE, RBMediaPlayerEntryTypePrivate))
+
+static void rb_media_player_entry_type_class_init (RBMediaPlayerEntryTypeClass *klass);
+static void rb_media_player_entry_type_init (RBMediaPlayerEntryType *etype);
 
 static void rb_media_player_source_class_init (RBMediaPlayerSourceClass *klass);
 static void rb_media_player_source_init (RBMediaPlayerSource *source);
@@ -101,9 +114,124 @@ enum
 {
 	PROP_0,
 	PROP_DEVICE_SERIAL,
-	PROP_ENCODING_TARGET
+	PROP_ENCODING_TARGET,
+	PROP_ENCODING_SETTINGS,
+	PROP_URI_PREFIX,
+	PROP_KEY_PREFIX,
 };
 
+static char *
+impl_uri_to_cache_key (RhythmDBEntryType *etype, const char *uri)
+{
+	RBMediaPlayerEntryTypePrivate *priv = MEDIA_PLAYER_ENTRY_TYPE_GET_PRIVATE (etype);
+
+	if (g_str_has_prefix (uri, priv->uri_prefix) == FALSE) {
+		return NULL;
+	}
+
+	return g_strconcat (priv->key_prefix, ":", uri + strlen (priv->uri_prefix), NULL);
+}
+
+static char *
+impl_cache_key_to_uri (RhythmDBEntryType *etype, const char *key)
+{
+	RBMediaPlayerEntryTypePrivate *priv = MEDIA_PLAYER_ENTRY_TYPE_GET_PRIVATE (etype);
+
+	if (g_str_has_prefix (key, priv->key_prefix) == FALSE) {
+		return NULL;
+	}
+
+	return g_strconcat (priv->uri_prefix, key + strlen (priv->key_prefix) + 1, NULL);
+}
+
+static void
+impl_entry_type_set_property (GObject *object,
+			      guint prop_id,
+			      const GValue *value,
+			      GParamSpec *pspec)
+{
+	RBMediaPlayerEntryTypePrivate *priv = MEDIA_PLAYER_ENTRY_TYPE_GET_PRIVATE (object);
+	switch (prop_id) {
+	case PROP_URI_PREFIX:
+		priv->uri_prefix = g_value_dup_string (value);
+		break;
+	case PROP_KEY_PREFIX:
+		priv->key_prefix = g_value_dup_string (value);
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+		break;
+	}
+}
+
+static void
+impl_entry_type_get_property (GObject *object,
+			      guint prop_id,
+			      GValue *value,
+			      GParamSpec *pspec)
+{
+	RBMediaPlayerEntryTypePrivate *priv = MEDIA_PLAYER_ENTRY_TYPE_GET_PRIVATE (object);
+	switch (prop_id) {
+	case PROP_URI_PREFIX:
+		g_value_set_string (value, priv->uri_prefix);
+		break;
+	case PROP_KEY_PREFIX:
+		g_value_set_string (value, priv->key_prefix);
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+		break;
+	}
+}
+
+static void
+impl_entry_type_finalize (GObject *object)
+{
+	RBMediaPlayerEntryTypePrivate *priv = MEDIA_PLAYER_ENTRY_TYPE_GET_PRIVATE (object);
+
+	g_free (priv->uri_prefix);
+	g_free (priv->key_prefix);
+
+	G_OBJECT_CLASS (rb_media_player_entry_type_parent_class)->finalize (object);
+}
+
+static void
+rb_media_player_entry_type_class_init (RBMediaPlayerEntryTypeClass *klass)
+{
+	RhythmDBEntryTypeClass *etype_class = RHYTHMDB_ENTRY_TYPE_CLASS (klass);
+	GObjectClass *object_class = G_OBJECT_CLASS (klass);
+
+	object_class->set_property = impl_entry_type_set_property;
+	object_class->get_property = impl_entry_type_get_property;
+	object_class->finalize = impl_entry_type_finalize;
+
+	/* sync_metadata? */
+	etype_class->uri_to_cache_key = impl_uri_to_cache_key;
+	etype_class->cache_key_to_uri = impl_cache_key_to_uri;
+
+	g_object_class_install_property (object_class,
+					 PROP_KEY_PREFIX,
+					 g_param_spec_string ("key-prefix",
+							      "key prefix",
+							      "metadata cache key prefix",
+							      NULL,
+							      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (object_class,
+					 PROP_URI_PREFIX,
+					 g_param_spec_string ("uri-prefix",
+							      "uri prefix",
+							      "uri prefix for entries",
+							      NULL,
+							      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+
+	g_type_class_add_private (klass, sizeof (RBMediaPlayerEntryTypePrivate));
+}
+
+static void
+rb_media_player_entry_type_init (RBMediaPlayerEntryType *etype)
+{
+}
+
 static void
 rb_media_player_source_class_init (RBMediaPlayerSourceClass *klass)
 {
@@ -155,6 +283,18 @@ rb_media_player_source_class_init (RBMediaPlayerSourceClass *klass)
 							      "GstEncodingTarget",
 							      GST_TYPE_ENCODING_TARGET,
 							      G_PARAM_READWRITE));
+	/**
+	 * RBMediaPlayerSource:encoding-settings
+	 *
+	 * The #GSettings instance holding encoding settings for this device
+	 */
+	g_object_class_install_property (object_class,
+					 PROP_ENCODING_SETTINGS,
+					 g_param_spec_object ("encoding-settings",
+							      "encoding settings",
+							      "GSettings holding encoding settings",
+							      G_TYPE_SETTINGS,
+							      G_PARAM_READWRITE));
 
 	g_type_class_add_private (klass, sizeof (RBMediaPlayerSourcePrivate));
 }
@@ -201,6 +341,12 @@ rb_media_player_source_set_property (GObject *object,
 		}
 		priv->encoding_target = GST_ENCODING_TARGET (g_value_dup_object (value));
 		break;
+	case PROP_ENCODING_SETTINGS:
+		if (priv->encoding_settings) {
+			g_object_unref (priv->encoding_settings);
+		}
+		priv->encoding_settings = g_value_dup_object (value);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		break;
@@ -221,6 +367,9 @@ rb_media_player_source_get_property (GObject *object,
 	case PROP_ENCODING_TARGET:
 		g_value_set_object (value, priv->encoding_target);
 		break;
+	case PROP_ENCODING_SETTINGS:
+		g_value_set_object (value, priv->encoding_settings);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		break;
@@ -326,15 +475,15 @@ rb_media_player_source_get_free_space (RBMediaPlayerSource *source)
  * rb_media_player_source_get_entries:
  * @source: the #RBMediaPlayerSource
  * @category: the sync category name
- * @entries: (element-type utf8 RB.RhythmDBEntry): map to hold the entries
+ * @map: (element-type utf8 RB.RhythmDBEntry): map to hold the entries
  */
 void
 rb_media_player_source_get_entries (RBMediaPlayerSource *source,
 				    const char *category,
-				    GHashTable *entries)
+				    GHashTable *map)
 {
 	RBMediaPlayerSourceClass *klass = RB_MEDIA_PLAYER_SOURCE_GET_CLASS (source);
-	klass->get_entries (source, category, entries);
+	klass->get_entries (source, category, map);
 }
 
 /**
@@ -342,19 +491,19 @@ rb_media_player_source_get_entries (RBMediaPlayerSource *source,
  * @source: the #RBMediaPlayerSource
  * @entries: (element-type RB.RhythmDBEntry) (transfer full): list of entries to delete
  * @callback: callback to call on completion
- * @user_data: (closure) (scope notified): data for callback
+ * @data: (closure) (scope notified): data for callback
  * @destroy_data: callback to free the callback data
  */
 void
 rb_media_player_source_delete_entries	(RBMediaPlayerSource *source,
 					 GList *entries,
 					 RBMediaPlayerSourceDeleteCallback callback,
-					 gpointer user_data,
+					 gpointer data,
 					 GDestroyNotify destroy_data)
 {
 	RBMediaPlayerSourceClass *klass = RB_MEDIA_PLAYER_SOURCE_GET_CLASS (source);
 
-	klass->delete_entries (source, entries, callback, user_data, destroy_data);
+	klass->delete_entries (source, entries, callback, data, destroy_data);
 }
 
 static void
@@ -455,6 +604,17 @@ rb_media_player_source_show_properties (RBMediaPlayerSource *source)
 	gtk_box_pack_start (GTK_BOX (container), rb_sync_state_ui_new (priv->sync_state), TRUE, TRUE, 0);
 	gtk_widget_show_all (GTK_WIDGET (container));
 
+	/* create encoding settings UI */
+	if (priv->encoding_settings) {
+		container = GTK_CONTAINER (gtk_builder_get_object (builder, "encoding-settings-container"));
+		gtk_container_add (container, rb_encoding_settings_new (priv->encoding_settings, priv->encoding_target, TRUE));
+		gtk_widget_show_all (GTK_WIDGET (container));
+	} else {
+		container = GTK_CONTAINER (gtk_builder_get_object (builder, "encoding-settings-frame"));
+		gtk_widget_hide (GTK_WIDGET (container));
+		gtk_widget_set_no_show_all (GTK_WIDGET (container), TRUE);
+	}
+
 	gtk_widget_show (GTK_WIDGET (priv->properties_dialog));
 
 	g_object_unref (builder);
@@ -829,6 +989,27 @@ _rb_media_player_source_add_to_map (GHashTable *map, RhythmDBEntry *entry)
 			     rhythmdb_entry_ref (entry));
 }
 
+void
+rb_media_player_source_purge_metadata_cache (RBMediaPlayerSource *source)
+{
+	RhythmDBEntryType *entry_type;
+	GSettings *settings;
+	char *prefix;
+	gulong max_age;
+
+	settings = g_settings_new ("org.gnome.rhythmbox.rhythmdb");
+	max_age = g_settings_get_int (settings, "grace-period");
+	g_object_unref (settings);
+
+	if (max_age > 0 && max_age < 20000) {
+		g_object_get (source, "entry-type", &entry_type, NULL);
+		g_object_get (entry_type, "key-prefix", &prefix, NULL);
+		rhythmdb_entry_type_purge_metadata_cache (entry_type, prefix, max_age * 60 * 60 * 24);
+		g_object_unref (entry_type);
+		g_free (prefix);
+	}
+}
+
 static void
 sync_action_cb (GSimpleAction *action, GVariant *parameter, gpointer data)
 {
