@@ -375,6 +375,7 @@ track_done_cb (RBTrackTransferBatch *batch,
 /**
  * rb_transfer_target_transfer:
  * @target: an #RBTransferTarget
+ * @settings: #GSettings instance holding encoding settings
  * @entries: (element-type RB.RhythmDBEntry): a #GList of entries to transfer
  * @defer: if %TRUE, don't start the transfer until
  *
@@ -386,7 +387,7 @@ track_done_cb (RBTrackTransferBatch *batch,
  * Return value: (transfer full): an #RBTrackTransferBatch, or NULL
  */
 RBTrackTransferBatch *
-rb_transfer_target_transfer (RBTransferTarget *target, GList *entries, gboolean defer)
+rb_transfer_target_transfer (RBTransferTarget *target, GSettings *settings, GList *entries, gboolean defer)
 {
 	RBTrackTransferQueue *xferq;
 	RBTaskList *tasklist;
@@ -409,7 +410,7 @@ rb_transfer_target_transfer (RBTransferTarget *target, GList *entries, gboolean
 	batch = g_object_steal_data (G_OBJECT (target), "transfer-target-batch");
 
 	if (batch == NULL) {
-		batch = rb_track_transfer_batch_new (NULL, NULL, G_OBJECT (target));
+		batch = rb_track_transfer_batch_new (NULL, settings, NULL, G_OBJECT (target));
 
 		g_signal_connect_object (batch, "get-dest-uri", G_CALLBACK (get_dest_uri_cb), target, 0);
 		g_signal_connect_object (batch, "track-done", G_CALLBACK (track_done_cb), target, 0);
