@@ -478,7 +478,7 @@ rb_property_view_new (RhythmDB *db,
 					       "vscrollbar_policy", GTK_POLICY_AUTOMATIC,
 					       "hexpand", TRUE,
 					       "vexpand", TRUE,
-					       "shadow_type", GTK_SHADOW_IN,
+					       "shadow_type", GTK_SHADOW_NONE,
 					       "db", db,
 					       "prop", propid,
 					       "title", title,
